Module lemonade

Module lemonade 

Lemonade OpenAI-compatible provider wire codec. Lemonade OpenAI-compatible provider wire codec.

Lemonade Server accepts OpenAI chat-completions request and response bodies. This module delegates the wire translation to the OpenAI codec while preserving the native lemonade provider identity on decoded transcripts.

Structs

LemonadeCodec
Runtime codec for Lemonade OpenAI-compatible chat-completion JSON.
LemonadeCodecLib
Host-registered lib for codec:lemonade.

Functions

decode_lemonade_request
Decodes a Lemonade OpenAI-compatible request body.
decode_lemonade_response
Decodes a Lemonade OpenAI-compatible response body.
decode_lemonade_stream
Decodes Lemonade OpenAI-compatible SSE chunks into a response transcript.
encode_lemonade_request
Encodes a model-request transcript into a Lemonade request body.
encode_lemonade_response
Encodes a model-response transcript into a Lemonade response body.
lemonade_codec_symbol
Returns the codec symbol codec:lemonade.

Type Aliases

LemonadeCodecOptions
Options for Lemonade OpenAI-compatible request JSON generation.
LemonadeRequestOptions
Alias for LemonadeCodecOptions when used for request generation.